// quizsetnames - array of titles for the rows that can be selected for a quiz.
//
var quizsetnames = ["a", "ka", "sa", "ta", "na", "ha", "ma", "ya", "ra", "wa",
	"n", "ga", "za", "da", "ba", "pa","kya","sha","cha","nya","hya","mya",
	"rya", "gya", "ja", "bya", "pya"];

// quizsets - array of arrays of associative arrays containing data on the kana.
// Each entry in the main array represents a single "row" in a standard kana
// chart, in the order they're usually learned. The fields in the associative array
// are, respectively:
//	h - hiragana representation (UTF-8)
//	k - katakana representation (UTF-8)
//	r - romaji representation
//	p - PlainTalk phonetic pronunciation (approximate), not currently used
//
// no, I didn't type this in by hand; Perl is your friend.
//
var quizsets = [
	// basic phonemes
	// (vowels)
	[{h:"あ", k:"ア", r:"a", p:">AA"},
	 {h:"い", k:"イ", r:"i", p:">IY"},
	 {h:"う", k:"ウ", r:"u", p:">UW"},
	 {h:"え", k:"エ", r:"e", p:">EH"},
	 {h:"お", k:"オ", r:"o", p:">OW"}],
	// K
	[{h:"か", k:"カ", r:"ka", p:"k>AA"},
	 {h:"き", k:"キ", r:"ki", p:"k>IY"},
	 {h:"く", k:"ク", r:"ku", p:"k>UW"},
	 {h:"け", k:"ケ", r:"ke", p:"k>EH"},
	 {h:"こ", k:"コ", r:"ko", p:"k>OW"}],
	// S
	[{h:"さ", k:"サ", r:"sa", p:"s>AA"},
	 {h:"し", k:"シ", r:"shi", p:"S>IY"},
	 {h:"す", k:"ス", r:"su", p:"s>UW"},
	 {h:"せ", k:"セ", r:"se", p:"s>EH"},
	 {h:"そ", k:"ソ", r:"so", p:"s>OW"}],
	// T
	[{h:"た", k:"タ", r:"ta", p:"t>AA"},
	 {h:"ち", k:"チ", r:"chi", p:"C>IY"},
	 {h:"つ", k:"ツ", r:"tsu", p:"ts>UW"},
	 {h:"て", k:"テ", r:"te", p:"t>EH"},
	 {h:"と", k:"ト", r:"to", p:"t>OW"}],
	// N
	[{h:"な", k:"ナ", r:"na", p:"n>AA"},
	 {h:"に", k:"ニ", r:"ni", p:"n>IY"},
	 {h:"ぬ", k:"ヌ", r:"nu", p:"n>UW"},
	 {h:"ね", k:"ネ", r:"ne", p:"n>EH"},
	 {h:"の", k:"ノ", r:"no", p:"n>OW"}],
	// H
	[{h:"は", k:"ハ", r:"ha", p:"h>AA"},
	 {h:"ひ", k:"ヒ", r:"hi", p:"h>IY"},
	 {h:"ふ", k:"フ", r:"fu", p:"f>UW"},
	 {h:"へ", k:"ヘ", r:"he", p:"h>EH"},
	 {h:"ほ", k:"ホ", r:"ho", p:"h>OW"}],
	// M
	[{h:"ま", k:"マ", r:"ma", p:"m>AA"},
	 {h:"み", k:"ミ", r:"mi", p:"m>IY"},
	 {h:"む", k:"ム", r:"mu", p:"m>UW"},
	 {h:"め", k:"メ", r:"me", p:"m>EH"},
	 {h:"も", k:"モ", r:"mo", p:"m>OW"}],
	// Y
	[{h:"や", k:"ヤ", r:"ya", p:"y>AA"},
	 {h:"ゆ", k:"ユ", r:"yu", p:"y>UW"},
	 {h:"よ", k:"ヨ", r:"yo", p:"y>OW"}],
	// R
	[{h:"ら", k:"ラ", r:"ra", p:"r>AA"},
	 {h:"り", k:"リ", r:"ri", p:"r>IY"},
	 {h:"る", k:"ル", r:"ru", p:"r>UW"},
	 {h:"れ", k:"レ", r:"re", p:"r>EH"},
	 {h:"ろ", k:"ロ", r:"ro", p:"r>OW"}],
	// W
	[{h:"わ", k:"ワ", r:"wa", p:"w>AA"},
	 {h:"を", k:"ヲ", r:"wo", p:">OW"}],
	// (n)
	[{h:"ん", k:"ン", r:"n", p:">>N"}],

	// vocalized phonemes
	// G
	[{h:"が", k:"ガ", r:"ga", p:"g>AA"},
	 {h:"ぎ", k:"ギ", r:"gi", p:"g>IY"},
	 {h:"ぐ", k:"グ", r:"gu", p:"g>UW"},
	 {h:"げ", k:"ゲ", r:"ge", p:"g>EH"},
	 {h:"ご", k:"ゴ", r:"go", p:"g>OW"}],
	// Z
	[{h:"ざ", k:"ザ", r:"za", p:"z>AA"},
	 {h:"じ", k:"ジ", r:"ji", p:"J>IY"},
	 {h:"ず", k:"ズ", r:"zu", p:"z>UW"},
	 {h:"ぜ", k:"ゼ", r:"ze", p:"z>EH"},
	 {h:"ぞ", k:"ゾ", r:"zo", p:"z>OW"}],
	// D
	[{h:"だ", k:"ダ", r:"da", p:"d>AA"},
	 {h:"ぢ", k:"ヂ", r:"di", p:"J>IY"},
	 {h:"づ", k:"ヅ", r:"du", p:"z>UW"},
	 {h:"で", k:"デ", r:"de", p:"d>EH"},
	 {h:"ど", k:"ド", r:"do", p:"d>OW"}],
	// B
	[{h:"ば", k:"バ", r:"ba", p:"b>AA"},
	 {h:"び", k:"ビ", r:"bi", p:"b>IY"},
	 {h:"ぶ", k:"ブ", r:"bu", p:"b>UW"},
	 {h:"べ", k:"ベ", r:"be", p:"b>EH"},
	 {h:"ぼ", k:"ボ", r:"bo", p:"b>OW"}],
	// P
	[{h:"ぱ", k:"パ", r:"pa", p:"p>AA"},
	 {h:"ぴ", k:"ピ", r:"pi", p:"p>IY"},
	 {h:"ぷ", k:"プ", r:"pu", p:"p>UW"},
	 {h:"ぺ", k:"ペ", r:"pe", p:"p>EH"},
	 {h:"ぽ", k:"ポ", r:"po", p:"p>OW"}],

	// combination phonemes
	// KY
	[{h:"きゃ", k:"キャ", r:"kya", p:"ky>AA"},
	 {h:"きゅ", k:"キュ", r:"kyu", p:"ky>UW"},
	 {h:"きょ", k:"キョ", r:"kyo", p:"ky>OW"}],
	// SH
	[{h:"しゃ", k:"シャ", r:"sha", p:"S>AA"},
	 {h:"しゅ", k:"シュ", r:"shu", p:"S>UW"},
	 {h:"しょ", k:"ショ", r:"sho", p:"S>OW"}],
	// CH
	[{h:"ちゃ", k:"チャ", r:"cha", p:"C>AA"},
	 {h:"ちゅ", k:"チュ", r:"chu", p:"C>UW"},
	 {h:"ちょ", k:"チョ", r:"cho", p:"C>OW"}],
	// NY
	[{h:"にゃ", k:"ニャ", r:"nya", p:"ny>AA"},
	 {h:"にゅ", k:"ニュ", r:"nyu", p:"ny>UW"},
	 {h:"にょ", k:"ニョ", r:"nyo", p:"ny>OW"}],
	// HY
	[{h:"ひゃ", k:"ヒャ", r:"hya", p:"hy>AA"},
	 {h:"ひゅ", k:"ヒュ", r:"hyu", p:"hy>UW"},
	 {h:"ひょ", k:"ヒョ", r:"hyo", p:"hy>OW"}],
	// MY
	[{h:"みゃ", k:"ミャ", r:"mya", p:"my>AA"},
	 {h:"みゅ", k:"ミュ", r:"myu", p:"my>UW"},
	 {h:"みょ", k:"ミョ", r:"myo", p:"my>OW"}],
	// RY
	[{h:"りゃ", k:"リャ", r:"rya", p:"ry>AA"},
	 {h:"りゅ", k:"リュ", r:"ryu", p:"ry>UW"},
	 {h:"りょ", k:"リョ", r:"ryo", p:"ry>OW"}],
	// GY
	[{h:"ぎゃ", k:"ギャ", r:"gya", p:"gy>AA"},
	 {h:"ぎゅ", k:"ギュ", r:"gyu", p:"gy>UW"},
	 {h:"ぎょ", k:"ギョ", r:"gyo", p:"gy>OW"}],
	// JA
	[{h:"じゃ", k:"ジャ", r:"ja", p:"j>AA"},
	 {h:"じゅ", k:"ジュ", r:"ju", p:"j>UW"},
	 {h:"じょ", k:"ジョ", r:"jo", p:"j>OW"}],
	// BY
	[{h:"びゃ", k:"ビャ", r:"bya", p:"by>AA"},
	 {h:"びゅ", k:"ビュ", r:"byu", p:"by>UW"},
	 {h:"びょ", k:"ビョ", r:"byo", p:"by>OW"}],
	// PY
	[{h:"ぴゃ", k:"ピャ", r:"pya", p:"py>AA"},
	 {h:"ぴゅ", k:"ピュ", r:"pyu", p:"py>UW"},
	 {h:"ぴょ", k:"ピョ", r:"pyo", p:"py>OW"}],
];
